==> etc-14.2.2-x86_64-1aAL.txz: usr/local/bin/shutdown.py <==
#!/usr/bin/env python
#
# c2007-2016 by Paul Sherman <psherman2001@gmail.com>
#									        #
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2	
# of the License, or (at your option) any later version.
#
# This script was written for use with Absolute Linux.
# For this script to work, you must have Python,
# and users must have the right to use the
# /sbin/shutdown command without need for a password.
# In your /etc/sudoers file have an alias set for shutdown
#
# Cmnd_Alias   SHUTDOWN=/sbin/shutdown
#
# and set the rights for users to include the above, a la:
#
# %users          ALL=NOPASSWD:SHUTDOWN
#
#
from Tkinter import *
import tkFont
import base64
import os, string, commands
cmd="sudo /sbin/shutdown -h now"
rcmd="sudo /sbin/shutdown -r now"
og = commands.getoutput('xgamma')

icon = \
"""iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAACg0lEQVQ4jaWTS2iVZxCGn+87/zE5
JsamCCIVjCAiSIUuxBsUBQM2QqEgtIK4KIGACxfFlhYK4rYbBd20goh1pQs1CsZrhRptigiiXQTU
BFFrpabxXL7L/13GxZHmbMUXZjMwz8w7wyAia0RkSt5dUyKyRonIVOvG+QF39ya5+ZrcaiKlR2KA
FBAUxEAOHlJErME06szbMcLy4W+nlYjIq4PfUx1YSa7/R5p9hXhLLksIAXJCYkCCR7wjmwZ2doap
v18yeOs5BUC2TXJjlmybiDNUB1bRu+1LKgv7AUgzL6mfPY4ZH0NKj1IKXa0CvAU0G+3OztD18ToW
DO2kdX0UM/EbkgI9Gwfp//o7dE8vr08fRURQRQdATIvcrNO1YjULhnYyc+QA7sEdpDRI6fD3xrET
V1n0w2Hik0eE21dQtKUBJEWys/Ru+wrz+xh+8h6SIx8du8bSk+OQI/aPy5gb51i4ay9IQknuADgD
zqL7PsDd/xMQlOZ/6QponbE3L1AsWYbOAXLssBBKpPRzFeptdABIgi7aSZVLVApzE2RvyN6RZv+l
+5ONQEbpOYIuFLpQzN/8BfHpQ1T06Fh2WPAW8Zb6mePM37CV7tVrQRIvRrbwz/B6lBJqn35O1/rP
aJ06hAoWCb7jjNagawYzPkaxaDH9Iz9iJ67ibl9Ekaht2k7X2kHs6M/4K79CKCGkjh14SzZNtAiN
0ROEJw/p2zFMbd1WAOKzR9QPf4O7dAIJEQmRlNpXUCIif234kGpvH6rWA0UVhbT3QKKSAyo6iB6C
A+ewLvK4KQxNCgUw3b1738DkLz9RmWehUiBAQSYjFDlSySWkRE4JnRKmFJbu2Q8wzfu+8xtNGuII
XIn2RAAAAABJRU5ErkJggg=="""

class App:

	def __init__(self, master):

		HEADERFONT = tkFont.Font(family='sans', size=18, weight='bold') 
		BOLDFONT = tkFont.Font(family='sans', size=12, weight='bold')
		frame = Frame(master)
		frame.configure(background = '#BFBFBF')

		self.lbl = Label(root, text="Shutdown the Machine?")
		self.lbl.configure(background = '#BFBFBF')
		self.lbl['font'] = HEADERFONT
		self.lbl.pack(side=TOP, pady=16)

		self.button = Button(frame, text=" Cancel ", activeforeground="red", highlightcolor="red", command=self.forgetIt)
		self.button['font'] = BOLDFONT
		self.button.bind('<Return>', self.forgetIt)
		self.button.focus_set()
		self.button.pack(side=LEFT, padx=10, pady=5)

		self.hi_there = Button(frame, text="Shutdown", activeforeground="red", highlightcolor="red", command=self.hasta_manana)
		self.hi_there['font'] = BOLDFONT
		self.hi_there.bind('<Return>', self.hasta_manana)
		self.hi_there.pack(side=LEFT, padx=10, pady=5)

		self.rboot = Button(frame, text="Reboot", activeforeground="red", highlightcolor="red", command=self.ill_be_back)
		self.rboot['font'] = BOLDFONT
		self.rboot.bind('<Return>', self.ill_be_back)
		self.rboot.pack(side=LEFT, padx=10, pady=5)
		frame.pack()

	def forgetIt(self, dummy=""):
		try:
			if og.split()[0] == '->':
				r, g, b = og.split()[2], og.split()[4], og.split()[6]
				cmd = 'xgamma -q -rgamma %s -ggamma %s -bgamma %s' % (r, g, b)
				os.system(cmd)
			else:
				os.system("xgamma -q -gamma 1.0")
		except:
			os.system("xgamma -q -gamma 1.0")
		sys.exit()
	
	
	def hasta_manana(self, dummy=""):
		self.hi_there.destroy()
		self.rboot.destroy()
		self.button.destroy()
		self.lbl.destroy()
		self.bye=Label(root, text="System will go down now...").pack()
		root.title("See Ya Later")
		os.system(cmd)


	def ill_be_back(self, dummy=""):
		self.hi_there.destroy()
		self.rboot.destroy()
		self.button.destroy()
		self.lbl.destroy()
		self.bye=Label(root, text="System will reboot now...").pack()
		root.title("I\'ll be back!")
		os.system(rcmd)

def callback():
	try:
		if og.split()[0] == '->':
			r, g, b = og.split()[2], og.split()[4], og.split()[6]
			cmd = 'xgamma -q -rgamma %s -ggamma %s -bgamma %s' % (r, g, b)
			os.system(cmd)
		else:
			os.system("xgamma -q -gamma 1.0")
	except:
		os.system("xgamma -q -gamma 1.0")
	sys.exit()

root = Tk()
app = App(root)
root.title("Confirmation Request")
root.protocol("WM_DELETE_WINDOW", callback)
scrX, scrY = root.winfo_screenwidth(), root.winfo_screenheight()
wStart = (scrX - 320) / 2
hStart = (scrY - 76) / 2
root.geometry("%dx%d%+d%+d" % (400, 120, wStart, hStart))
root.configure(background = '#BFBFBF')
img = PhotoImage(data=icon)
root.tk.call('wm', 'iconphoto', root._w, img)
os.system("xgamma -q -gamma 0.5")
root.mainloop()

==> etc-15.1-x86_64-20230315AL.txz: usr/local/bin/shutdown.py <==
#!/usr/bin/env python3
#
# c2007-2018 by Paul Sherman <psherman2001@gmail.com>
#									        #
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2	
# of the License, or (at your option) any later version.
#
# This script was written for use with Absolute Linux.
# For this script to work, you must have Python,
# and users must have the right to use the
# /sbin/shutdown command without need for a password.
# In your /etc/sudoers file have an alias set for shutdown
#
# Cmnd_Alias   SHUTDOWN=/sbin/shutdown
#
# and set the rights for users to include the above, a la:
#
# %users          ALL=NOPASSWD:SHUTDOWN
#
#
from tkinter import *
import tkinter.font
import base64
import os, string, subprocess
cmd="sudo /sbin/shutdown -h now"
rcmd="sudo /sbin/shutdown -r now"
og = subprocess.getoutput('xgamma')

icon = \
"""iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAACg0lEQVQ4jaWTS2iVZxCGn+87/zE5
JsamCCIVjCAiSIUuxBsUBQM2QqEgtIK4KIGACxfFlhYK4rYbBd20goh1pQs1CsZrhRptigiiXQTU
BFFrpabxXL7L/13GxZHmbMUXZjMwz8w7wyAia0RkSt5dUyKyRonIVOvG+QF39ya5+ZrcaiKlR2KA
FBAUxEAOHlJErME06szbMcLy4W+nlYjIq4PfUx1YSa7/R5p9hXhLLksIAXJCYkCCR7wjmwZ2doap
v18yeOs5BUC2TXJjlmybiDNUB1bRu+1LKgv7AUgzL6mfPY4ZH0NKj1IKXa0CvAU0G+3OztD18ToW
DO2kdX0UM/EbkgI9Gwfp//o7dE8vr08fRURQRQdATIvcrNO1YjULhnYyc+QA7sEdpDRI6fD3xrET
V1n0w2Hik0eE21dQtKUBJEWys/Ru+wrz+xh+8h6SIx8du8bSk+OQI/aPy5gb51i4ay9IQknuADgD
zqL7PsDd/xMQlOZ/6QponbE3L1AsWYbOAXLssBBKpPRzFeptdABIgi7aSZVLVApzE2RvyN6RZv+l
+5ONQEbpOYIuFLpQzN/8BfHpQ1T06Fh2WPAW8Zb6mePM37CV7tVrQRIvRrbwz/B6lBJqn35O1/rP
aJ06hAoWCb7jjNagawYzPkaxaDH9Iz9iJ67ibl9Ekaht2k7X2kHs6M/4K79CKCGkjh14SzZNtAiN
0ROEJw/p2zFMbd1WAOKzR9QPf4O7dAIJEQmRlNpXUCIif234kGpvH6rWA0UVhbT3QKKSAyo6iB6C
A+ewLvK4KQxNCgUw3b1738DkLz9RmWehUiBAQSYjFDlSySWkRE4JnRKmFJbu2Q8wzfu+8xtNGuII
XIn2RAAAAABJRU5ErkJggg=="""

class App:

	def __init__(self, master):

		HEADERFONT = tkinter.font.Font(family='sans', size=18, weight='bold') 
		BOLDFONT = tkinter.font.Font(family='sans', size=12, weight='bold')
		frame = Frame(master)
		frame.configure(background = '#BFBFBF')

		self.lbl = Label(root, text="Shutdown the Machine?")
		self.lbl.configure(background = '#BFBFBF')
		self.lbl['font'] = HEADERFONT
		self.lbl.pack(side=TOP, pady=16)

		self.button = Button(frame, text=" Cancel ", activeforeground="red", highlightcolor="red", command=self.forgetIt)
		self.button['font'] = BOLDFONT
		self.button.bind('<Return>', self.forgetIt)
		self.button.focus_set()
		self.button.pack(side=LEFT, padx=10, pady=5)

		self.hi_there = Button(frame, text="Shutdown", activeforeground="red", highlightcolor="red", command=self.hasta_manana)
		self.hi_there['font'] = BOLDFONT
		self.hi_there.bind('<Return>', self.hasta_manana)
		self.hi_there.pack(side=LEFT, padx=10, pady=5)

		self.rboot = Button(frame, text="Reboot", activeforeground="red", highlightcolor="red", command=self.ill_be_back)
		self.rboot['font'] = BOLDFONT
		self.rboot.bind('<Return>', self.ill_be_back)
		self.rboot.pack(side=LEFT, padx=10, pady=5)
		frame.pack()

	def forgetIt(self, dummy=""):
		try:
			if og.split()[0] == '->':
				r, g, b = og.split()[2], og.split()[4], og.split()[6]
				cmd = 'xgamma -q -rgamma %s -ggamma %s -bgamma %s' % (r, g, b)
				os.system(cmd)
			else:
				os.system("xgamma -q -gamma 1.0")
		except:
			os.system("xgamma -q -gamma 1.0")
		sys.exit()
	
	
	def hasta_manana(self, dummy=""):
		self.hi_there.destroy()
		self.rboot.destroy()
		self.button.destroy()
		self.lbl.destroy()
		self.bye=Label(root, text="System will go down now...").pack()
		root.title("See Ya Later")
		os.system(cmd)


	def ill_be_back(self, dummy=""):
		self.hi_there.destroy()
		self.rboot.destroy()
		self.button.destroy()
		self.lbl.destroy()
		self.bye=Label(root, text="System will reboot now...").pack()
		root.title("I\'ll be back!")
		os.system(rcmd)

def callback():
	try:
		if og.split()[0] == '->':
			r, g, b = og.split()[2], og.split()[4], og.split()[6]
			cmd = 'xgamma -q -rgamma %s -ggamma %s -bgamma %s' % (r, g, b)
			os.system(cmd)
		else:
			os.system("xgamma -q -gamma 1.0")
	except:
		os.system("xgamma -q -gamma 1.0")
	sys.exit()

root = Tk()
app = App(root)
root.title("Confirmation Request")
root.protocol("WM_DELETE_WINDOW", callback)
scrX, scrY = root.winfo_screenwidth(), root.winfo_screenheight()
wStart = (scrX - 320) / 2
hStart = (scrY - 76) / 2
root.geometry("%dx%d%+d%+d" % (400, 120, wStart, hStart))
root.configure(background = '#BFBFBF')
img = PhotoImage(data=icon)
root.tk.call('wm', 'iconphoto', root._w, img)
os.system("xgamma -q -gamma 0.75")
root.mainloop()
